%
% prettyPlot(lh, clrs, stys)
%   lh is a figure handle
%   clrs is a vector of color indices (table in this function)
%   stys is a cell array of line styles
%
% Example:
%   figure(1)
%   lh = loglog(f, [Sh_sqz, Sh_high, Sh_base, Sh_therm, Sh_total]);
%   legend('Quantum Noise, 6dB Squeezing', ...
%       'Quantum Noise, 4-fold Power Increase ', ...
%       'Quantum Noise (Baseline)', ...
%       'Thermal Noise', ...
%       'Total Noise (Baseline)')
% 
%   clrs = [5 7 6 2 4];
%   stys = {'-', '-', '-.', '-.', '--'};
%   prettyPlot(lh, clrs, stys)
%   reorderPlot([], [1 5 4 3 2])
%
function prettyPlot(lh, clrs, stys)

  clrtable = [1.0   0.2   0.1    % thermal
              1.0   0.6   0.3    % faded thermal
              0.0   0.0   0.0    % total
              0.5   0.5   0.5    % faded total
              0.7   0.0   0.9    % quantum
              0.9   0.5   1.0    % faded quantum
              0.0   0.5   0.0    % high power
              0.0   0.3   1.0    % squeeze
              0.75   0.75   0.75];
          
  % colors and line styles
  for n = 1:numel(lh)
    set(lh(n), 'color', clrtable(clrs(n),:), 'linestyle', stys{n});
  end
  
  % grid, axis
  grid on
  ylim([1e-24, 1e-22])
  
  % labels
  xlabel('Frequency [Hz]')
  ylabel('Strain Sensitivity [1/\surd{Hz}]')
  
  % for printing
  orient rotated
  
end


